# JollyJack

## Features

- Reading parquet data from parquet file directly into numpy array

## Required:

- pyarrow  ~= 16.0
 
JollyJack operates on top of pyarrow, making it an essential requirement for both building and using PalletJack. While our source package is compatible with recent versions of pyarrow, the binary distribution package specifically requires the latest major version of pyarrow.

##  Installation

```
pip install jollyjack
```

## How to use:

### TODO:
```

```
